==> ejc-salary-impl-3.0.0-20241022.063253-41-sources.jar: com/ejianc/business/salary/bean/JspayableSourceEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资明细来源
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_source")
public class JspayableSourceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_detail_id")
    private Long jspayableDetailId; // 所属明细id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="month")
    private Date month; // 月份
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="source_id")
    private Long sourceId; // 应发上传id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 应发上传明细id
    @TableField(value="period")
    private Date period; // 期间 应发工资计算的 月份


    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}

==> ejc-salary-impl-3.0.0-20241129.064655-72-sources.jar: com/ejianc/business/salary/bean/JspayableSourceEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资明细来源
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_source")
public class JspayableSourceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_detail_id")
    private Long jspayableDetailId; // 所属明细id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="month")
    private Date month; // 月份
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="source_id")
    private Long sourceId; // 应发上传id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 应发上传明细id
    @TableField(value="period")
    private Date period; // 期间 应发工资计算的 月份
    @TableField(value="company_id")
    private Long companyId; // 汇总单所属公司id
    @TableField(value="company_name")
    private String companyName; // 汇总单所属公司

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }


    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}
